# Copyright (C) 2009 Mark A. Matienzo
#
# This file is part of iii, the Python Innovative Interfaces utility module.
#
# iii is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# iii is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with iii.  If not, see <http://www.gnu.org/licenses/>.

# __init__.py

__version__ = '0.1'

from iii import checkdigits

def main():
    pass

if __name__ == '__main__':
    main()